@@ -790,6 +790,8 @@ class DocumentController():
             assert(not self._hasNoAssociatedFile)
             filename = self.filename()
         try:
+            if util.isWindows() and isinstance(filename, (list,tuple)):
+                filename = filename[0]
             with open(filename, 'w') as f:
                 helixOrderList = self.win.pathroot.getSelectedPartOrderedVHList()
                 encode(self._document, helixOrderList, f)
